@@ -86,8 +86,7 @@ class EncoderDecoderLM:
 
         # load model
         self.tokenizer, self.model, self.config = get_lm(
-            model, use_auth_token=use_auth_token, torch_dtype=torch_dtype, device_map=device_map,
-            low_cpu_mem_usage=low_cpu_mem_usage)
+            model, use_auth_token=use_auth_token, torch_dtype=torch_dtype, device_map=device_map, low_cpu_mem_usage=low_cpu_mem_usage)
         if self.tokenizer.pad_token is None:
             self.tokenizer.pad_token = "<<PAD>>"
         if max_length_encoder is None:
@@ -105,17 +104,13 @@ class EncoderDecoderLM:
         self.loss_fct = torch.nn.CrossEntropyLoss(reduction='none')
 
         # GPU setup
-        if device is None:
-            self.device = 'cuda' if torch.cuda.device_count() > 0 else 'cpu'
-        else:
-            self.device = device
-        num_gpus = torch.cuda.device_count() if num_gpus is None else num_gpus
-        if num_gpus > 1:
-            self.parallel = True
-            self.model = torch.nn.DataParallel(self.model)
-        self.model.to(self.device)
+        if device_map is None:
+            num_gpus = torch.cuda.device_count() if num_gpus is None else num_gpus
+            if num_gpus > 0:
+                self.model = torch.nn.DataParallel(self.model) if num_gpus > 1 else self.model
+                self.model.to(device)
+        logging.info(f'\t * model is loaded on: {self.model.device}')
         self.model.eval()
-        logging.info(f'\t * Num of GPU in use: {torch.cuda.device_count()}')
 
     def get_perplexity(self, input_texts: str or List, output_texts: str or List, batch: int = None):
         """ Compute the perplexity on decoder of the seq2seq model.
@@ -156,11 +151,11 @@ class EncoderDecoderLM:
                 label = output_encode["input_ids"]
                 label[label == self.tokenizer.pad_token_id] = PAD_TOKEN_LABEL_ID
                 # label = torch.concat([label[:, 1:], torch.tensor([[PAD_TOKEN_LABEL_ID] * label.shape[0]]).T], dim=1)
-                model_inputs["labels"] = label.to(self.device)
+                model_inputs["labels"] = label.to(self.model.device)
 
                 # model run & loss conversion into likelihood
                 valid_length = (model_inputs["labels"] != PAD_TOKEN_LABEL_ID).sum(dim=-1)
-                output = self.model(**{k: v.to(self.device) for k, v in model_inputs.items()})
+                output = self.model(**{k: v.to(self.model.device) for k, v in model_inputs.items()})
                 loss = self.loss_fct(output['logits'].view(-1, self.config.vocab_size), model_inputs["labels"].view(-1))
                 loss = loss.view(len(output['logits']), -1)
                 loss = torch.sum(loss, -1) / valid_length
